ColCollection

Type Alias ColCollection 

pub type ColCollection<'scope, T> = Collection<'scope, T, Column<(Row, T, Diff)>>;
A columnar collection of (Row, Diff) updates, which is what a dataflow edge between Plan nodes carries.

Aliased Type

pub struct ColCollection<'scope, T> {
    pub inner: Stream<'scope, T, Column<(Row, T, Overflowing<i64>)>>,
}

Fields

inner: Stream<'scope, T, Column<(Row, T, Overflowing<i64>)>>

The underlying timely dataflow stream.

This field is exposed to support direct timely dataflow manipulation when required, but it is not intended to be the idiomatic way to work with the collection.

The timestamp in the data is required to always be at least the timestamp of the data, in the timely-dataflow sense. If this invariant is not upheld, differential operators may behave unexpectedly.