pub type ColumnarCollection<'scope, T, D, R> = Collection<'scope, T, Column<(D, T, R)>>;Expand description
A columnar collection of (D, T, R) updates traveling on a compute
dataflow edge.
Mirrors differential’s VecCollection<'scope, T, D, R>; the underlying
container is Column<(D, T, R)> instead of Vec<(D, T, R)>.
Aliased Type
pub struct ColumnarCollection<'scope, T, D, R> {
pub inner: Stream<'scope, T, Column<(D, T, R)>>,
}Fields
inner: Stream<'scope, T, Column<(D, T, R)>>The underlying timely dataflow stream.
This field is exposed to support direct timely dataflow manipulation when required, but it is not intended to be the idiomatic way to work with the collection.
The timestamp in the data is required to always be at least the timestamp of the data, in the timely-dataflow sense. If this invariant is not upheld, differential operators may behave unexpectedly.